@@ -1,5 +1,7 @@
-__version__ = "6.3.0"
-__version_info__ = (6, 3, 0, "", "")
+__version__ = "6.5.1.1"
+__version_info__ = (6, 5, 1.1, "", "")
+__minimum_python_version__ = None
+__maximum_python_version__ = None
 
 # PYSIDE-932: Python 2 cannot import 'zipfile' for embedding while being imported, itself.
 # We simply pre-load all imports for the signature extension.
@@ -23,6 +25,3 @@ import functools
 import typing
 
 from shiboken6.Shiboken import *
-
-# Trigger signature initialization via __builtins__.
-_init_pyside_extension()
